@@ -36,6 +36,7 @@ class Server:
         self._server = None
         self._running_port = 0
         self._running_stage = 0  # 0: off / 1: pending / 2: running
+        self._running_future = None
         self._name = name
         self._www = None
         self._options = options
@@ -98,7 +99,7 @@ class Server:
 
     def _push_state(self, state):
         if self.protocol:
-            self.protocol.push_state_change(utils.clean_state(state))
+            self.protocol.push_state_change(state)
 
     # -------------------------------------------------------------------------
     # Initialization helper
@@ -270,6 +271,18 @@ class Server:
             help="Use OS built-in browser",
             action="store_true",
         )
+        self._cli_parser.add_argument(
+            "--no-http",
+            help="Do not serve anything over http",
+            dest="no_http",
+            action="store_true",
+        )
+        self._cli_parser.add_argument(
+            "--authKeyFile",
+            help="""Path to a File that contains the Authentication key for clients
+                    to connect to the WebSocket.
+                    This takes precedence over '-a, --authKey' from wslink.""",
+        )
 
         CoreServer.add_arguments(self._cli_parser)
 
@@ -304,16 +317,23 @@ class Server:
         """Return True if the server is currently starting or running."""
         return self._running_stage > 1
 
+    @property
+    def ready(self):
+        """Return a future that will resolve once the server is ready"""
+        if self._running_future is None:
+            self._running_future = asyncio.get_running_loop().create_future()
+
+        return self._running_future
+
     # -------------------------------------------------------------------------
     # API for network handling
     # -------------------------------------------------------------------------
 
     def get_server_state(self):
         """Return the current server state"""
-        shared_state = utils.clean_state(self.state.initial)
         state = {
             "name": self._name,
-            "state": shared_state,
+            "state": self.state.initial,
         }
         return state
 
@@ -456,6 +476,11 @@ class Server:
                     endpoints.append(f"{key}={value}")
             options.fsEndpoints = "|".join(endpoints)
 
+        # Reset http delivery
+        if options.no_http:
+            options.content = ""
+            options.fsEndpoints = ""
+
         CoreServer.configure(options)
 
         self._running_stage = 1
@@ -495,6 +520,7 @@ class Server:
         """Coroutine for stopping the server"""
         if self._running_stage:
             await self._server.stop()
+            self._running_future = None
 
     @property
     def port(self):
